Xdatasets documentation
=======================

**Useful links**: Coming Soon!


The ``xdatasets`` library enables users to effortlessly access a vast collection of large-scale earth observation datasets that are compatible with `xarray` formats all through a single query.

The library adopts an opinionated approach to data querying and caters to the specific needs of certain user groups, such as hydrologists, climate scientists, and engineers.

The genesis of this project can be traced back to a crucial requirement of effortlessly sharing standard earth observation data sources during inter-organizational collaboration. Although the advent of cloud computing has streamlined the data centralization process, it cannot be denied that there is still a considerable learning curve involved in accessing these datasets and leveraging them for practical engineering computations.

.. toctree::
   :maxdepth: 2
   :caption: Contents:
   :hidden:

   readme
   installation
   usage
   notebooks/getting_started
   apidoc/modules
   contributing
   authors
   changes

.. Indices and tables
.. ==================
.. * :ref:`genindex`
.. * :ref:`modindex`
.. * :ref:`search`
